/* Muses72323 code for Arduino Uno
 *  
*/

#include <Muses72323.h>

#define STANDBY          0
#define MAX_INPUT        3
#define MAX_PARAMETER    46
#define MAX_ATTENUATION -472
#define STEP             0.25 

// The address wired into the MUSES chip (usually 0).
static const byte MUSES_ADDRESSR = 0;
static const byte MUSES_ADDRESSL = 1;

static Muses72320 MusesR(MUSES_ADDRESSR);
static Muses72320 MusesL(MUSES_ADDRESSL);
static Muses72320::volume_t CurrentVolume = -80;
int16_t parameters[MAX_PARAMETER+1];

bool mute = false ;
int input_index = 0;
int inputs[] = {4, 5, 6, 7};  // Replace with the actual pin numbers you are using for inputs
const int PRE_ON = 8;  // Replace with the actual pin number for PRE_ON
const int AMP_ON = 9;  // Replace with the actual pin number for AMP_ON
int status_index=STANDBY; //0 STANDBY 1 PRE-ON 2 AMP ON


void SetupMuses()
{
  // Initialize MUSES (SPI, pin modes)...
  MusesR.setExternalClock(false); // Must be set !!!
  MusesR.setZeroCrossingOn(true);
  MusesL.setExternalClock(false); // Must be set !!!
  MusesL.setZeroCrossingOn(true);
}

void muted()
{
  MusesR.setVolume(MAX_ATTENUATION, MAX_ATTENUATION);
  MusesL.setVolume(MAX_ATTENUATION, MAX_ATTENUATION);
  mute = true;
}

// RP, RM, LP, and LM represent the volume levels for the right channel and left channel of an audio system.
// These variables are used to set the volume of both the right and left channels independently.
// Here's what each variable stands for:
// RP: R ch volume for the plus offset. This is the volume level for the right channel when it has a positive offset.
// RM: R ch volume for the minus offset. This is the volume level for the right channel when it has a negative offset.
// LP: L ch volume for the plus offset. This is the volume level for the left channel when it has a positive offset.
// LM: L ch volume for the minus offset. This is the volume level for the left channel when it has a negative offset.

void Update_Volume()
{
  int16_t RP, RM, LP, LM;
  RP = parameters[0] + parameters[((input_index + 1) * 10)];
  RM = parameters[0] + parameters[((input_index + 1) * 10) + 1];
  LP = parameters[0] + parameters[((input_index + 1) * 10) + 2];
  LM = parameters[0] + parameters[((input_index + 1) * 10) + 3];
  if (RP < MAX_ATTENUATION) RP = MAX_ATTENUATION;
  if (RM < MAX_ATTENUATION) RM = MAX_ATTENUATION;
  if (LP < MAX_ATTENUATION) LP = MAX_ATTENUATION;
  if (LM < MAX_ATTENUATION) LM = MAX_ATTENUATION;
  MusesR.setVolume(RP, RM);
  MusesL.setVolume(LP, LM);
}

void select_Input(int val)
{
  muted();

  for (int i = 0; i <= MAX_INPUT; i++)
  {
    digitalWrite(inputs[i], LOW);
  }

  digitalWrite(inputs[val], HIGH);

  Update_Volume();
}

void status_Update()
{
  if (status_index == 0)
  {
    muted();
    digitalWrite(PRE_ON, LOW);
    digitalWrite(AMP_ON, LOW);
  //  lcd.noBacklight();
  }
  if (status_index == 1)
  {
    muted();

    SetupMuses();

    Update_Volume();
  }
  if (status_index == 2)
  {
    muted();

    delay(1000);
    Update_Volume();
  }
}

void setup()
{
  // ... (the rest of your setup code)




  // Initialize MUSES
  SetupMuses();
  // ... (the rest of your setup code)
}

void loop() {
  // Ramping up volume from 0dB to -111.75dB in 0.25dB steps
  for (int volume = 0; volume >= -11175; volume -= 25) {
    Update_Volume();
    delay(10);  // Adjust the delay as needed for the desired speed of the ramp.
  }

  // Other loop code...

  // You can continue with the rest of your loop code here.
}
